@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cmark
-version: 0.5.1
-id: cmark-0.5.1-28550a213c384aabe08ba531c632e415
-key: cmark_Cw1x90zMYkW9qlo27SQTs3
+version: 0.5.2
+id: cmark-0.5.2-f48a7256a8c75efe8918f0ce1d08f0cd
+key: cmark_363z1z8YrzQ880CFtwE1eX
 license: BSD3
 copyright: (C) 2015 John MacFarlane
 maintainer: jgm@berkeley.edu
@@ -14,7 +14,7 @@ description:
     <https://github.com/jgm/cmark libcmark>, the reference
     parser for <http://commonmark.org CommonMark>, a fully
     specified variant of Markdown. It includes sources for
-    libcmark (0.24.1) and does not require prior installation of the
+    libcmark (0.25.2) and does not require prior installation of the
     C library.
 category: Text
 author: John MacFarlane
@@ -22,16 +22,16 @@ exposed: True
 exposed-modules:
     CMark
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/cmark-0.5.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/cmark-0.5.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/cmark-0.5.1
-hs-libraries: HScmark-0.5.1-Cw1x90zMYkW9qlo27SQTs3
-includes:
-    cmark.h
+import-dirs: /usr/lib/ghc-7.10.3/site-local/cmark-0.5.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/cmark-0.5.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/cmark-0.5.2
+hs-libraries: HScmark-0.5.2-363z1z8YrzQ880CFtwE1eX
+extra-libraries:
+    cmark
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-cmark/html/cmark.haddock
 haddock-html: /usr/share/doc/haskell-cmark/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
